netapp_ontap.models.shelf_temperature_sensors API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_temperature_sensors`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfTemperatureSensorsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfTemperatureSensors object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `ambient: bool GET POST PATCH`

    Sensor that measures the ambient temperature

    Example: false

  `id: Size GET POST PATCH`

    The id field of the shelf_temperature_sensors.

    Example: 1

  `installed: bool GET POST PATCH`

    The installed field of the shelf_temperature_sensors.

    Example: true

  `location: str GET POST PATCH`

    The location field of the shelf_temperature_sensors.

    Example: temp sensor on midplane left

  `state: str GET POST PATCH`

    The state field of the shelf_temperature_sensors.

    Valid choices:

    - ok
    - error
  `temperature: Size GET POST PATCH`

    Temperature, in degrees Celsius

    Example: 32

  `threshold: ShelfTemperatureSensorsThreshold GET POST PATCH`

    The threshold field of the shelf_temperature_sensors.